@@ -13,6 +13,8 @@ val product : ('a -> 'b -> 'c) -> 'a list -> 'b list -> 'c list
 val pi : 'a list list -> 'a list list
   (** pi [l1; .. ; lN] returns the list of the certesian product l1 * .. * lN *)
 
+val tri : 'a list -> ('a * 'a) list
+
 val nth_power : 'a list -> int -> 'a list list
 
 val power : 'a list -> 'a list list
@@ -35,6 +37,8 @@ val count : 'a list -> ('a * int) list
 
 val fold_left1 : ('a -> 'a -> 'a) -> 'a list -> 'a
 
+val concat_map : ('a -> 'b list) -> 'a list -> 'b list 
+
 (* list operations for integer lists. *)
 
 val max : int list -> int
@@ -50,3 +54,6 @@ val index : ?i:int -> 'a list -> (int * 'a) list
 val take : int -> 'a list -> 'a list
 
 val drop : int -> 'a list -> 'a list
+
+(* misc *)
+val count_iter : ?n:int -> ('a -> unit) -> 'a list -> unit
